#pragma once

#include <kylin-ai/ai-engine/embeddingengine.h>

namespace ai_engine {
namespace core_ai {
namespace embedding {
class EmbeddingServer;

class OndeviceEmbeddingEngine : public AbstractEmbeddingEngine {
public:
    OndeviceEmbeddingEngine();
    ~OndeviceEmbeddingEngine();
    void setEmbeddingResultCallback(EmbeddingResultCallback callback);

    // 引擎的名称
    std::string engineName() const { return "ondevice-embedding-engine"; }

    // 是否是云端引擎
    bool isCloud() const { return false; }

    // 是否是内置引擎
    // AI子系统提供内置的模型，调用者不可以指定和切换模型
    // 包括向量化模型、OCR等
    bool isBuiltInEngine() const { return true; }

    // 引擎使用的模型信息
    // json格式的字符串，包括模型的名称，厂商，需要的配置信息等
    // 向量化
    std::string modelInfo() const;

    ///[0] 文本向量化
    result::AiEngineBaseResult initTextEmbeddingModule();
    result::AiEngineBaseResult destroyTextEmbeddingModule();
    result::AiEngineBaseResult embeddingText(const std::string &text);
    ///[0]

    ///[1] 图像向量化
    result::AiEngineBaseResult initImageEmbeddingModule();
    result::AiEngineBaseResult destroyImageEmbeddingModule();
    result::AiEngineBaseResult embeddingImageFromImageFile(
        const std::string &filePath);
    result::AiEngineBaseResult embeddingImageFromBase64ImageData(
        const std::string &fileData);
    result::AiEngineBaseResult embeddingTextWithImageModel(
        const std::string &text);
    ///[1]

private:
    EmbeddingServer *embeddingServer_ = nullptr;
};
}  // namespace embedding
}  // namespace core_ai
}  // namespace ai_engine
